@@ -3,8 +3,8 @@
 /**
  * @file classes/core/Application.inc.php
  *
- * Copyright (c) 2014-2020 Simon Fraser University
- * Copyright (c) 2003-2020 John Willinsky
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2003-2021 John Willinsky
  * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class Application
@@ -136,6 +136,7 @@ class Application extends PKPApplication {
 			'importexport',
 			'oaiMetadataFormats',
 			'paymethod',
+			'reports',
 		);
 	}
 
@@ -146,22 +147,6 @@ class Application extends PKPApplication {
 		return DAORegistry::getDAO('PressDAO');
 	}
 
-	/**
-	 * Get the context settings DAO.
-	 * @return SettingsDAO
-	 */
-	public static function getContextSettingsDAO() {
-		return DAORegistry::getDAO('PressSettingsDAO');
-	}
-
-	/**
-	 * Get the submission DAO.
-	 * @deprecated Just use DAORegistry::getDAO('SubmissionDAO') directly.
-	 */
-	public static function getSubmissionDAO() {
-		return DAORegistry::getDAO('SubmissionDAO');
-	}
-
 	/**
 	 * Get the section DAO.
 	 * @return SeriesDAO
@@ -192,36 +177,6 @@ class Application extends PKPApplication {
 		return DAORegistry::getDAO('MonographSearchDAO');
 	}
 
-	/**
-	 * returns the name of the context column in plugin_settings
-	 */
-	public static function getPluginSettingsContextColumnName() {
-		if (defined('SESSION_DISABLE_INIT')) {
-			$pluginSettingsDao = DAORegistry::getDAO('PluginSettingsDAO'); /* @var $pluginSettingsDao PluginSettingsDAO */
-			$driver = $pluginSettingsDao->getDriver();
-			switch ($driver) {
-				case 'mysql':
-				case 'mysqli':
-					$checkResult = $pluginSettingsDao->retrieve('SHOW COLUMNS FROM plugin_settings LIKE ?', array('context_id'));
-					if ($checkResult->NumRows() == 0) {
-						return 'press_id';
-					}
-					break;
-				case 'postgres':
-				case 'postgres64':
-				case 'postgres7':
-				case 'postgres8':
-				case 'postgres9':
-					$checkResult = $pluginSettingsDao->retrieve('SELECT column_name FROM information_schema.columns WHERE table_name= ? AND column_name= ?', array('plugin_settings', 'context_id'));
-					if ($checkResult->NumRows() == 0) {
-						return 'press_id';
-					}
-					break;
-			}
-		}
-		return 'context_id';
-	}
-
 	/**
 	 * Get the stages used by the application.
 	 */
