@@ -3,8 +3,8 @@
 /**
  * @file classes/log/MonographFileEmailLogDAO.inc.php
  *
- * Copyright (c) 2014-2020 Simon Fraser University
- * Copyright (c) 2003-2020 John Willinsky
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2003-2021 John Willinsky
  * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class MonographFileEmailLogDAO
@@ -18,13 +18,6 @@ import('lib.pkp.classes.log.EmailLogDAO');
 import('classes.log.MonographFileEmailLogEntry');
 
 class MonographFileEmailLogDAO extends EmailLogDAO {
-	/**
-	 * Constructor
-	 */
-	function __construct() {
-		parent::__construct();
-	}
-
 	/**
 	 * Instantiate and return a MonographFileEmailLogEntry.
 	 * @return MonographFileEmailLogEntry
