@@ -3,8 +3,8 @@
 /**
  * @file classes/publicationFormat/PublicationFormatTombstoneManager.inc.php
  *
- * Copyright (c) 2014-2020 Simon Fraser University
- * Copyright (c) 2000-2020 John Willinsky
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2000-2021 John Willinsky
  * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class PublicationFormatTombstoneManager
@@ -84,7 +84,13 @@ class PublicationFormatTombstoneManager {
 		$submissionsIterator = Services::get('submission')->getMany(['contextId' => $press->getId(), 'status' => STATUS_PUBLISHED, 'count' => 2000]);
 		foreach ($submissionsIterator as $submission) {
 			foreach ($submission->getData('publications') as $publication) {
-				$this->insertTombstonesByPublicationFormats($publication->getData('publicationFormats'), $press);
+				if ($publication->getData('status') === STATUS_PUBLISHED) {
+					foreach ((array) $publication->getData('publicationFormats') as $publicationFormat) {
+						if ($publication->getIsAvailable()) {
+							$this->insertTombstoneByPublicationFormat($publicationFormat, $press);
+						}
+					}
+				}
 			}
 		}
 	}
@@ -113,6 +119,39 @@ class PublicationFormatTombstoneManager {
 			}
 		}
 	}
+
+	/**
+	 * Delete tombstones for every publication format in a publication
+	 *
+	 * @param int $publicationId
+	 */
+	function deleteTombstonesByPublicationId(int $publicationId) {
+		$publicationFormats = DAORegistry::getDAO('PublicationFormatDAO')
+			->getByPublicationId($publicationId)
+			->toArray();
+		$this->deleteTombstonesByPublicationFormats($publicationFormats);
+	}
+
+	/**
+	 * Insert tombstones for every available publication format in a publication
+	 *
+	 * This method will delete any existing tombstones to ensure that duplicates
+	 * are not created.
+	 *
+	 * @param int $publicationId
+	 * @param Press $context
+	 */
+	function insertTombstonesByPublicationId(int $publicationId, $context) {
+		$this->deleteTombstonesByPublicationId($publicationId);
+		$publicationFormats = DAORegistry::getDAO('PublicationFormatDAO')
+			->getByPublicationId($publicationId)
+			->toArray();
+		foreach ($publicationFormats as $publicationFormat) {
+			if ($publicationFormat->getIsAvailable()) {
+				$this->insertTombstoneByPublicationFormat($publicationFormat, $context);
+			}
+		}
+	}
 }
 
 
