@@ -32,31 +32,47 @@ class SubmissionSubmitStep4Form extends PKPSubmissionSubmitStep4Form {
 
 		// Send author notification email
 		import('classes.mail.MonographMailTemplate');
-		$mail = new MonographMailTemplate($this->submission, 'SUBMISSION_ACK', null, null, false);
-		$authorMail = new MonographMailTemplate($this->submission, 'SUBMISSION_ACK_NOT_USER', null, null, false);
 
 		$request = Application::get()->getRequest();
 		$context = $request->getContext();
 		$router = $request->getRouter();
+		$user = $request->getUser();
+
+		$mail = new MonographMailTemplate($this->submission, 'SUBMISSION_ACK', null, null, false);
 		if ($mail->isEnabled()) {
 			// submission ack emails should be from the contact.
 			$mail->setFrom($this->context->getData('contactEmail'), $this->context->getData('contactName'));
+			$mail->addRecipient($user->getEmail(), $user->getFullName());
+			$mail->bccAssignedSeriesEditors($this->submissionId, WORKFLOW_STAGE_ID_SUBMISSION);
+			$mail->assignParams([
+				'authorName' => htmlspecialchars($user->getFullName()),
+				'authorUsername' => htmlspecialchars($user->getUsername()),
+				'editorialContactSignature' => htmlspecialchars($context->getData('contactName')) . '<br/>' . htmlspecialchars($context->getLocalizedName()),
+				'submissionUrl' => $router->url($request, null, 'authorDashboard', 'submission', $this->submissionId),
+			]);
+
+			if (!$mail->send($request)) {
+				import('classes.notification.NotificationManager');
+				$notificationMgr = new NotificationManager();
+				$notificationMgr->createTrivialNotification($request->getUser()->getId(), NOTIFICATION_TYPE_ERROR, array('contents' => __('email.compose.error')));
+			}
+		}
+
+		$authorMail = new MonographMailTemplate($this->submission, 'SUBMISSION_ACK_NOT_USER', null, null, false);
+		if ($authorMail->isEnabled()) {
 			$authorMail->setFrom($this->context->getData('contactEmail'), $this->context->getData('contactName'));
 
-			$user = $request->getUser();
 			$primaryAuthor = $this->submission->getPrimaryAuthor();
 			if (!isset($primaryAuthor)) {
 				$authors = $this->submission->getAuthors();
 				$primaryAuthor = $authors[0];
 			}
-			$mail->addRecipient($user->getEmail(), $user->getFullName());
 
 			if ($user->getEmail() != $primaryAuthor->getEmail()) {
 				$authorMail->addRecipient($primaryAuthor->getEmail(), $primaryAuthor->getFullName());
 			}
 
 			$assignedAuthors = $this->submission->getAuthors();
-
 			foreach ($assignedAuthors as $author) {
 				$authorEmail = $author->getEmail();
 				// only add the author email if they have not already been added as the primary author
@@ -65,34 +81,16 @@ class SubmissionSubmitStep4Form extends PKPSubmissionSubmitStep4Form {
 					$authorMail->addRecipient($author->getEmail(), $author->getFullName());
 				}
 			}
-			$mail->bccAssignedSeriesEditors($this->submissionId, WORKFLOW_STAGE_ID_SUBMISSION);
-
-			$mail->assignParams([
-				'authorName' => htmlspecialchars($user->getFullName()),
-				'authorUsername' => htmlspecialchars($user->getUsername()),
-				'editorialContactSignature' => htmlspecialchars($context->getData('contactName')) . '<br/>' . htmlspecialchars($context->getLocalizedName()),
-				'submissionUrl' => $router->url($request, null, 'authorDashboard', 'submission', $this->submissionId),
-			]);
-
 			$authorMail->assignParams([
 				'submitterName' => htmlspecialchars($user->getFullName()),
 				'editorialContactSignature' => htmlspecialchars($context->getData('contactName')) . "<br/>" . htmlspecialchars($context->getLocalizedName()),
 			]);
 
-			if (!$mail->send($request)) {
+			if (!empty($authorMail->getRecipients()) && !$authorMail->send($request)) {
 				import('classes.notification.NotificationManager');
 				$notificationMgr = new NotificationManager();
 				$notificationMgr->createTrivialNotification($request->getUser()->getId(), NOTIFICATION_TYPE_ERROR, array('contents' => __('email.compose.error')));
 			}
-
-			$recipients = $authorMail->getRecipients();
-			if (!empty($recipients)) {
-				if (!$authorMail->send($request)) {
-					import('classes.notification.NotificationManager');
-					$notificationMgr = new NotificationManager();
-					$notificationMgr->createTrivialNotification($request->getUser()->getId(), NOTIFICATION_TYPE_ERROR, array('contents' => __('email.compose.error')));
-				}
-			}
 		}
 
 		// Log submission.
