@@ -3,8 +3,8 @@
 /**
  * @file classes/template/TemplateManager.inc.php
  *
- * Copyright (c) 2014-2020 Simon Fraser University
- * Copyright (c) 2003-2020 John Willinsky
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2003-2021 John Willinsky
  * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class TemplateManager
@@ -43,10 +43,10 @@ class TemplateManager extends PKPTemplateManager {
 			$this->assign('publicFilesDir', $siteFilesDir); // May be overridden by press
 
 			// Pass app-specific details to template
-			$this->assign(array(
+			$this->assign([
 				'brandImage' => 'templates/images/omp_brand.png',
 				'packageKey' => 'common.software',
-			));
+			]);
 
 			// Get a count of unread tasks.
 			if ($user = $request->getUser()) {
@@ -63,9 +63,6 @@ class TemplateManager extends PKPTemplateManager {
 					'publicFilesDir' => $request->getBaseUrl() . '/' . $publicFileManager->getContextFilesPath($context->getId()),
 					'primaryLocale' => $context->getPrimaryLocale(),
 					'supportedLocales' => $context->getSupportedLocaleNames(),
-					'displayPageHeaderTitle' => $context->getLocalizedPageHeaderTitle(),
-					'displayPageHeaderLogo' => $context->getLocalizedPageHeaderLogo(),
-					'displayPageHeaderLogoAltText' => $context->getLocalizedData('pageHeaderLogoImageAltText'),
 					'numPageLinks' => $context->getData('numPageLinks'),
 					'itemsPerPage' => $context->getData('itemsPerPage'),
 					'enableAnnouncements' => $context->getData('enableAnnouncements'),
@@ -78,43 +75,71 @@ class TemplateManager extends PKPTemplateManager {
 					$this->addStyleSheet(
 						'contextStylesheet',
 						$request->getBaseUrl() . '/' . $publicFileManager->getContextFilesPath($context->getId()) . '/' . $contextStyleSheet['uploadName'],
-						array(
-							'priority' => STYLE_SEQUENCE_LAST
-						)
+						['priority' => STYLE_SEQUENCE_LAST]
 					);
 				}
 
-				// Get a link to the settings page for the current context.
-				// This allows us to reduce template duplication by using this
-				// variable in templates/common/header.tpl, instead of
-				// reproducing a lot of OMP/OJS-specific logic there.
-				$dispatcher = $request->getDispatcher();
-				$this->assign( 'contextSettingsUrl', $dispatcher->url($request, ROUTE_PAGE, null, 'management', 'settings', 'context') );
-
 				$this->assign('pageFooter', $context->getLocalizedData('pageFooter'));
 			} else {
 				// Check if registration is open for any contexts
 				$contextDao = Application::getContextDAO();
 				$contexts = $contextDao->getAll(true)->toArray();
-				$contextsForRegistration = array();
+				$contextsForRegistration = [];
 				foreach($contexts as $context) {
 					if (!$context->getData('disableUserReg')) {
 						$contextsForRegistration[] = $context;
 					}
 				}
 
-				$this->assign(array(
+				$this->assign([
 					'contexts' => $contextsForRegistration,
 					'disableUserReg' => empty($contextsForRegistration),
-					'displayPageHeaderTitle' => $site->getLocalizedPageHeaderTitle(),
-					'displayPageHeaderLogo' => $site->getLocalizedData('pageHeaderTitleImage'),
 					'siteTitle' => $site->getLocalizedTitle(),
 					'primaryLocale' => $site->getPrimaryLocale(),
 					'supportedLocales' => $site->getSupportedLocaleNames(),
 					'pageFooter' => $site->getLocalizedData('pageFooter'),
-				));
-
+				]);
 			}
 		}
 	}
+
+	/**
+	 * @copydoc PKPTemplateManager::setupBackendPage()
+	 */
+	function setupBackendPage() {
+		parent::setupBackendPage();
+
+		$request = Application::get()->getRequest();
+		if (defined('SESSION_DISABLE_INIT')
+				|| !$request->getContext()
+				|| !$request->getUser()) {
+			return;
+		}
+
+		$router = $request->getRouter();
+		$handler = $router->getHandler();
+		$userRoles = (array) $handler->getAuthorizedContextObject(ASSOC_TYPE_USER_ROLES);
+
+		$menu = (array) $this->getState('menu');
+
+		// Add catalog after submissions items
+		if (in_array(ROLE_ID_MANAGER, $userRoles)) {
+			$catalogLink = [
+				'name' => __('navigation.catalog'),
+				'url' => $router->url($request, null, 'manageCatalog'),
+				'isCurrent' => $request->getRequestedPage() === 'manageCatalog',
+			];
+
+			$index = array_search('submissions', array_keys($menu));
+			if ($index === false || count($menu) <= ($index + 1)) {
+				$menu['catalog'] = $catalogLink;
+			} else {
+				$menu = array_slice($menu, 0, $index + 1, true) +
+						['catalog' => $catalogLink] +
+						array_slice($menu, $index + 1, null, true);
+			}
+		}
+
+		$this->setState(['menu' => $menu]);
+	}
 }
