@@ -3,8 +3,8 @@
 /**
  * @file controllers/grid/catalogEntry/PublicationDateGridHandler.inc.php
  *
- * Copyright (c) 2014-2020 Simon Fraser University
- * Copyright (c) 2000-2020 John Willinsky
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2000-2021 John Willinsky
  * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class PublicationDateGridHandler
@@ -127,7 +127,7 @@ class PublicationDateGridHandler extends GridHandler {
 		// Retrieve the associated publication format for this grid.
 		$publicationDateId = (int) $request->getUserVar('publicationDateId'); // set if editing or deleting a date
 
-		if ($publicationDateId != '') {
+		if ($publicationDateId) {
 			$publicationDateDao = DAORegistry::getDAO('PublicationDateDAO'); /* @var $publicationDateDao PublicationDateDAO */
 			$publicationDate = $publicationDateDao->getById($publicationDateId, $this->getPublication()->getId());
 			if ($publicationDate) {
@@ -332,19 +332,15 @@ class PublicationDateGridHandler extends GridHandler {
 
 		$publicationDateDao = DAORegistry::getDAO('PublicationDateDAO'); /* @var $publicationDateDao PublicationDateDAO */
 		$publicationDate = $publicationDateDao->getById($publicationDateId, $this->getPublication()->getId());
-		if ($publicationDate != null) { // authorized
-
-			$result = $publicationDateDao->deleteObject($publicationDate);
-
-			if ($result) {
-				$currentUser = $request->getUser();
-				$notificationMgr = new NotificationManager();
-				$notificationMgr->createTrivialNotification($currentUser->getId(), NOTIFICATION_TYPE_SUCCESS, array('contents' => __('notification.removedPublicationDate')));
-				return DAO::getDataChangedEvent();
-			} else {
-				return new JSONMessage(false, __('manager.setup.errorDeletingItem'));
-			}
+		if (!$publicationDate) {
+			return new JSONMessage(false, __('manager.setup.errorDeletingItem'));
 		}
+
+		$publicationDateDao->deleteObject($publicationDate);
+		$currentUser = $request->getUser();
+		$notificationMgr = new NotificationManager();
+		$notificationMgr->createTrivialNotification($currentUser->getId(), NOTIFICATION_TYPE_SUCCESS, array('contents' => __('notification.removedPublicationDate')));
+		return DAO::getDataChangedEvent();
 	}
 }
 
