@@ -3,8 +3,8 @@
 /**
  * @file controllers/grid/content/spotlights/ManageSpotlightsGridHandler.inc.php
  *
- * Copyright (c) 2014-2020 Simon Fraser University
- * Copyright (c) 2000-2020 John Willinsky
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2000-2021 John Willinsky
  * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class SpotlightsGridHandler
@@ -283,19 +283,15 @@ class ManageSpotlightsGridHandler extends GridHandler {
 		$spotlightDao = DAORegistry::getDAO('SpotlightDAO'); /* @var $spotlightDao SpotlightDAO */
 		$press = $this->getPress();
 		$spotlight = $spotlightDao->getById($spotlightId, $press->getId());
-		if ($spotlight != null) { // authorized
-
-			$result = $spotlightDao->deleteObject($spotlight);
-
-			if ($result) {
-				$currentUser = $request->getUser();
-				$notificationMgr = new NotificationManager();
-				$notificationMgr->createTrivialNotification($currentUser->getId(), NOTIFICATION_TYPE_SUCCESS, array('contents' => __('notification.removedSpotlight')));
-				return DAO::getDataChangedEvent();
-			} else {
-				return new JSONMessage(false, __('manager.setup.errorDeletingItem'));
-			}
+		if (!$spotlight) {
+			return new JSONMessage(false, __('manager.setup.errorDeletingItem'));
 		}
+
+		$spotlightDao->deleteObject($spotlight);
+		$currentUser = $request->getUser();
+		$notificationMgr = new NotificationManager();
+		$notificationMgr->createTrivialNotification($currentUser->getId(), NOTIFICATION_TYPE_SUCCESS, array('contents' => __('notification.removedSpotlight')));
+		return DAO::getDataChangedEvent();
 	}
 
 	/**
