@@ -3,8 +3,8 @@
 /**
  * @file pages/reviewer/PKPReviewerHandler.inc.php
  *
- * Copyright (c) 2014-2020 Simon Fraser University
- * Copyright (c) 2003-2020 John Willinsky
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2003-2021 John Willinsky
  * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class PKPReviewerHandler
@@ -19,6 +19,9 @@ import('lib.pkp.classes.submission.reviewer.ReviewerAction');
 
 class PKPReviewerHandler extends Handler {
 
+	/** @copydoc PKPHandler::_isBackendPage */
+	var $_isBackendPage = true;
+
 	/**
 	 * Display the submission review page.
 	 * @param $args array
@@ -33,14 +36,17 @@ class PKPReviewerHandler extends Handler {
 		$this->setupTemplate($request);
 
 		$templateMgr = TemplateManager::getManager($request);
-		$templateMgr->assign('submission', $reviewerSubmission);
 		$reviewStep = max($reviewerSubmission->getStep(), 1);
 		$userStep = (int) $request->getUserVar('step');
 		$step = (int) (!empty($userStep) ? $userStep: $reviewStep);
 		if ($step > $reviewStep) $step = $reviewStep; // Reviewer can't go past incomplete steps
-		if ($step < 1 || $step > 4) fatalError('Invalid step!');
-		$templateMgr->assign('reviewStep', $reviewStep);
-		$templateMgr->assign('selected', $step - 1);
+		if ($step < 1 || $step > 4) throw new Exception('Invalid step!');
+		$templateMgr->assign([
+			'pageTitle' => __('semicolon', ['label' => __('submission.review')]) . ' ' . $reviewerSubmission->getLocalizedTitle(),
+			'reviewStep' => $reviewStep,
+			'selected' => $step - 1,
+			'submission' => $reviewerSubmission,
+		]);
 
 		$templateMgr->display('reviewer/review/reviewStepHeader.tpl');
 	}
@@ -109,7 +115,7 @@ class PKPReviewerHandler extends Handler {
 			$notificationMgr = new NotificationManager();
 			$user = $request->getUser();
 			$notificationMgr->createTrivialNotification($user->getId(), NOTIFICATION_TYPE_SUCCESS, array('contents' => __('common.changesSaved')));
-			return DAO::getDataChangedEvent();			
+			return DAO::getDataChangedEvent();
 		}
 		// Submit the form data and move forward
 		else {
@@ -219,5 +225,3 @@ class PKPReviewerHandler extends Handler {
 		return $reviewId;
 	}
 }
-
-
