@@ -3,8 +3,8 @@
 /**
  * @file pages/management/SettingsHandler.inc.php
  *
- * Copyright (c) 2014-2020 Simon Fraser University
- * Copyright (c) 2003-2020 John Willinsky
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2003-2021 John Willinsky
  * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class SettingsHandler
@@ -36,6 +36,17 @@ class SettingsHandler extends ManagementHandler {
 		);
 	}
 
+	/**
+	 * @copydoc ManagementHandler::website()
+	 */
+	function website($args, $request) {
+		AppLocale::requireComponents(
+			LOCALE_COMPONENT_PKP_SUBMISSION,
+			LOCALE_COMPONENT_APP_SUBMISSION
+		);
+		parent::website($args, $request);
+	}
+
 	/**
 	 * Add the workflow settings page
 	 *
