@@ -3,8 +3,8 @@
 /**
  * @file pages/search/SearchHandler.inc.php
  *
- * Copyright (c) 2014-2020 Simon Fraser University
- * Copyright (c) 2003-2020 John Willinsky
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2003-2021 John Willinsky
  * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class SearchHandler
@@ -42,10 +42,13 @@ class SearchHandler extends Handler {
 		$query = $request->getUserVar('query');
 		$templateMgr->assign('searchQuery', $query);
 
+		// Get the range info.
+		$rangeInfo = $this->getRangeInfo($request, 'search');
+
 		// Fetch the monographs to display
 		$monographSearch = new MonographSearch();
 		$error = null;
-		$results = $monographSearch->retrieveResults($request, $press, array(null => $query), $error);
+		$results = $monographSearch->retrieveResults($request, $press, array(null => $query), $error, null, null, $rangeInfo);
 		$templateMgr->assign('results', $results);
 
 		// Display
