@@ -3,8 +3,8 @@
 /**
  * @file plugins/generic/googleScholar/GoogleScholarPlugin.inc.php
  *
- * Copyright (c) 2014-2020 Simon Fraser University
- * Copyright (c) 2003-2020 John Willinsky
+ * Copyright (c) 2014-2021 Simon Fraser University
+ * Copyright (c) 2003-2021 John Willinsky
  * Distributed under the GNU GPL v3. For full terms see the file docs/COPYING.
  *
  * @class GoogleScholarPlugin
@@ -51,6 +51,7 @@ class GoogleScholarPlugin extends GenericPlugin {
 
 		$publication = $submission->getCurrentPublication();
 		$press = $request->getContext();
+		$series = $templateMgr->getTemplateVars('series');
 		$availableFiles = $templateMgr->getTemplateVars('availableFiles');
 
 
@@ -58,14 +59,19 @@ class GoogleScholarPlugin extends GenericPlugin {
 		$templateMgr->addHeader('googleScholarRevision', '<meta name="gs_meta_revision" content="1.1"/>');
 
 		// Book/Edited volume title of the submission
-		$templateMgr->addHeader('googleScholarTitle', '<meta name="citation_title" content="' . htmlspecialchars($publication->getLocalizedTitle()) . '"/>');
+		$templateMgr->addHeader('googleScholarTitle', '<meta name="citation_title" content="' . htmlspecialchars($publication->getLocalizedFullTitle($submission->getLocale())) . '"/>');
+		// Language
+		if ($locale = $submission->getLocale()) {
+            $templateMgr->addHeader('googleScholarLanguage', '<meta name="citation_language" content="' . htmlspecialchars(substr($locale, 0, 2)) . '"/>');
+        }
 
 		// Publication date
 		$templateMgr->addHeader('googleScholarDate', '<meta name="citation_publication_date" content="' . strftime('%Y-%m-%d', strtotime($publication->getData('datePublished'))) . '"/>');
 
 		// Authors in order
+		$authors = $submission->getAuthors();
 		$i = 0;
-		foreach ($submission->getAuthors() as $author) {
+		foreach ($authors as $author) {
 			$templateMgr->addHeader('googleScholarAuthor' . $i++, '<meta name="citation_author" content="' . htmlspecialchars($author->getFullName(false)) . '"/>');
 		}
 
@@ -80,11 +86,6 @@ class GoogleScholarPlugin extends GenericPlugin {
 			$templateMgr->addHeader('googleScholarPublicationDOI', '<meta name="citation_doi" content="' . htmlspecialchars($publication->getData('pub-id::doi')) . '"/>');
 		}
 
-		// Language
-		if ($languages = $publication->getData('languages')) foreach ($languages as $language) {
-			$templateMgr->addHeader('googleScholarLanguage', '<meta name="citation_language" content="' . htmlspecialchars($language) . '"/>');
-		}
-
 		// Subjects
 		$i = 0;
 		$submissionSubjectDao = DAORegistry::getDAO('SubmissionSubjectDAO');
@@ -116,14 +117,14 @@ class GoogleScholarPlugin extends GenericPlugin {
 							$templateMgr->addHeader('googleScholarIsbn' . $i++, '<meta name="citation_isbn" content="' . htmlspecialchars($identificationCode->getValue()) . '"/>');
 						}
 					}
-						switch ($availableFile->getFileType()) {
-							case 'application/pdf':
-								$templateMgr->addHeader('googleScholarPdfUrl' . $i++, '<meta name="citation_pdf_url" content="' . $request->url(null, 'catalog', 'view', array($submission->getData('id'), $availableFile->getData('assocId'), $availableFile->getFileIdAndRevision())) . '"/>');
-								break;
-							case 'text/xml' or 'text/html':
-								$templateMgr->addHeader('googleScholarPdfUrl' . $i++, '<meta name="citation_fulltext_html_url" content="' . $request->url(null, 'catalog', 'view', array($submission->getData('id'), $availableFile->getData('assocId'), $availableFile->getFileIdAndRevision())) . '"/>');
-								break;
-						}
+					switch ($availableFile->getData('mimetype')) {
+						case 'application/pdf':
+							$templateMgr->addHeader('googleScholarPdfUrl' . $i++, '<meta name="citation_pdf_url" content="' . $request->url(null, 'catalog', 'download', array($submission->getData('id'), $availableFile->getData('assocId'), $availableFile->getData('id'))) . '"/>');
+							break;
+						case 'text/xml' or 'text/html':
+							$templateMgr->addHeader('googleScholarPdfUrl' . $i++, '<meta name="citation_fulltext_html_url" content="' . $request->url(null, 'catalog', 'download', array($submission->getData('id'), $availableFile->getData('assocId'), $availableFile->getData('id'))) . '"/>');
+							break;
+					}
 
 				}
 			}
