@@ -127,13 +127,13 @@ class NativeXmlPublicationFilter extends NativeXmlPKPPublicationFilter {
 
 		$existingDeployment = $this->getDeployment();
 		$request = Application::get()->getRequest();
-		
+
 		$onixDeployment = new Onix30ExportDeployment($request->getContext(), $request->getUser());
 		$onixDeployment->setPublication($existingDeployment->getPublication());
 		$onixDeployment->setFileDBIds($existingDeployment->getFileDBIds());
 		$onixDeployment->setAuthorDBIds($existingDeployment->getAuthorDBIds());
 		$importFilter->setDeployment($existingDeployment);
-		$formatDoc = new DOMDocument();
+		$formatDoc = new DOMDocument('1.0', 'utf-8');
 		$formatDoc->appendChild($formatDoc->importNode($n, true));
 		return $importFilter->execute($formatDoc);
 	}
@@ -177,7 +177,7 @@ class NativeXmlPublicationFilter extends NativeXmlPKPPublicationFilter {
 		$request = Application::get()->getRequest();
 
 		$importFilter->setDeployment($existingDeployment);
-		$chapterDoc = new DOMDocument();
+		$chapterDoc = new DOMDocument('1.0', 'utf-8');
 		$chapterDoc->appendChild($chapterDoc->importNode($n, true));
 		return $importFilter->execute($chapterDoc);
 	}
@@ -229,16 +229,35 @@ class NativeXmlPublicationFilter extends NativeXmlPKPPublicationFilter {
 		for ($n = $node->firstChild; $n !== null; $n=$n->nextSibling) {
 			if (is_a($n, 'DOMElement')) {
 				switch ($n->tagName) {
-					case 'cover_image': 
-						$coverImage['uploadName'] = uniqid() . '-' . basename($n->textContent);
+					case 'cover_image':
+						$coverImage['uploadName'] = uniqid() . '-' . basename(preg_replace(
+							"/[^a-z0-9\.\-]+/",
+							'',
+							str_replace(
+								[' ', '_', ':'],
+								'-',
+								strtolower($n->textContent)
+							)
+						));
 						break;
 					case 'cover_image_alt_text':
-						$coverImage['altText'] = $n->textContent; 
+						$coverImage['altText'] = $n->textContent;
 						break;
 					case 'embed':
+						if (!isset($coverImage['uploadName'])) {
+							$deployment->addWarning(ASSOC_TYPE_PUBLICATION, $object->getId(), __('plugins.importexport.common.error.coverImageNameUnspecified'));
+							break;
+						}
+
 						import('classes.file.PublicFileManager');
 						$publicFileManager = new PublicFileManager();
 						$filePath = $publicFileManager->getContextFilesPath($context->getId()) . '/' . $coverImage['uploadName'];
+						$allowedFileTypes = ['gif', 'jpg', 'png', 'webp'];
+						$extension = pathinfo(strtolower($filePath), PATHINFO_EXTENSION);
+						if (!in_array($extension, $allowedFileTypes)) {
+							$deployment->addWarning(ASSOC_TYPE_PUBLICATION, $object->getId(), __('plugins.importexport.common.error.invalidFileExtension'));
+							break;
+						}
 						file_put_contents($filePath, base64_decode($n->textContent));
 						break;
 					default:
