@@ -106,9 +106,9 @@ class Dc11SchemaPublicationFormatAdapter extends MetadataDataObjectAdapter {
 		$this->_addLocalizedElements($dc11Description, 'dc:description', $monograph->getAbstract(null));
 
 		// Publisher
-		$publisherInstitution = $press->getSetting('publisherInstitution');
-		if (!empty($publisherInstitution)) {
-			$publishers = [$press->getPrimaryLocale() => $publisherInstitution];
+		$publisher = $press->getSetting('publisher');
+		if (!empty($publisher)) {
+			$publishers = [$press->getPrimaryLocale() => $publisher];
 		} else {
 			$publishers = $press->getName(null); // Default
 		}
@@ -246,4 +246,3 @@ class Dc11SchemaPublicationFormatAdapter extends MetadataDataObjectAdapter {
 		}
 	}
 }
-
